@@ -2,7 +2,7 @@ context('partial attaching')
 
 test_that('partial attach works locally', {
     a = box::use(mod/a[double])
-    expect_equal(ls(parent.env(environment())), 'double')
+    expect_setequal(ls(parent.env(environment())), 'double')
 })
 
 test_that('partial attach works globally', {
@@ -10,12 +10,12 @@ test_that('partial attach works globally', {
     local(box::use(a = mod/a[inc, get_counter]), envir = .GlobalEnv)
     expect_equal(search()[2L], environmentName(a))
     on.exit(detach(), add = TRUE)
-    expect_equal(sort(ls(2L)), c('get_counter', 'inc'))
+    expect_setequal(ls(2L), c('get_counter', 'inc'))
 })
 
 test_that('Invalid attach specifier raises error', {
-    expect_error(
+    expect_box_error(
         box::use(mod/a[foo, bar]),
-        regexp = 'Names .* not exported by'
+        regexp = 'names .* not exported by'
     )
 })
