@@ -8,18 +8,18 @@ test_that('module reexport exposes the correct names', {
     direct_exports = c('a', 'c')
     sub_exports = c('d', 'e')
     all_expected_exports = c(direct_exports, sub_exports, 'sub')
-    expect_equal(sort(exports), sort(all_expected_exports))
+    expect_setequal(exports, all_expected_exports)
 })
 
 test_that('module reexports the correct names', {
     box::use(x = mod/reexport)
 
     exported_names = c('a', 'c', 'sub', 'd', 'e')
-    expect_true('a' %in% ls(x))
-    expect_false('b' %in% ls(x))
-    expect_true('c' %in% ls(x))
-    expect_true('sub' %in% ls(x))
-    expect_true('d' %in% ls(x))
+    expect_in('a', ls(x))
+    expect_not_in('b', ls(x))
+    expect_in('c', ls(x))
+    expect_in('sub', ls(x))
+    expect_in('d', ls(x))
 })
 
 test_that('module reexport names refer to correct objects', {
